SWDEV-339113 - update coordinate in HIP sample kernels (#2736)

Change-Id: I8ea179b4ba8f1c0ebec830a5aa5947e843f06e42

[ROCm/hip-tests commit: dea8404361]
This commit is contained in:
ROCm CI Service Account
2022-06-15 11:22:27 +05:30
committed by GitHub
szülő 0b4dabc65e
commit 47af0feeb0
6 fájl változott, egészen pontosan 10 új sor hozzáadva és 10 régi sor törölve
@@ -36,7 +36,7 @@ THE SOFTWARE.
// Device (Kernel) function, it must be void
__global__ void matrixTranspose(float* out, float* in, const int width) {
int x = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
int x = blockDim.x * blockIdx.x + threadIdx.x;
float val = in[x];